<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'greenwichský střední čas (Abidžan)',
        'Africa/Accra' => 'greenwichský střední čas (Accra)',
        'Africa/Addis_Ababa' => 'východoafrický čas (Addis Abeba)',
        'Africa/Algiers' => 'středoevropský čas (Alžír)',
        'Africa/Asmera' => 'východoafrický čas (Asmara)',
        'Africa/Bamako' => 'greenwichský střední čas (Bamako)',
        'Africa/Bangui' => 'západoafrický čas (Bangui)',
        'Africa/Banjul' => 'greenwichský střední čas (Banjul)',
        'Africa/Bissau' => 'greenwichský střední čas (Bissau)',
        'Africa/Blantyre' => 'středoafrický čas (Blantyre)',
        'Africa/Brazzaville' => 'západoafrický čas (Brazzaville)',
        'Africa/Bujumbura' => 'středoafrický čas (Bujumbura)',
        'Africa/Cairo' => 'východoevropský čas (Káhira)',
        'Africa/Casablanca' => 'západoevropský čas (Casablanca)',
        'Africa/Ceuta' => 'středoevropský čas (Ceuta)',
        'Africa/Conakry' => 'greenwichský střední čas (Conakry)',
        'Africa/Dakar' => 'greenwichský střední čas (Dakar)',
        'Africa/Dar_es_Salaam' => 'východoafrický čas (Dar es Salaam)',
        'Africa/Djibouti' => 'východoafrický čas (Džibuti)',
        'Africa/Douala' => 'západoafrický čas (Douala)',
        'Africa/El_Aaiun' => 'západoevropský čas (El Aaiun)',
        'Africa/Freetown' => 'greenwichský střední čas (Freetown)',
        'Africa/Gaborone' => 'středoafrický čas (Gaborone)',
        'Africa/Harare' => 'středoafrický čas (Harare)',
        'Africa/Johannesburg' => 'jihoafrický čas (Johannesburg)',
        'Africa/Juba' => 'středoafrický čas (Juba)',
        'Africa/Kampala' => 'východoafrický čas (Kampala)',
        'Africa/Khartoum' => 'středoafrický čas (Chartúm)',
        'Africa/Kigali' => 'středoafrický čas (Kigali)',
        'Africa/Kinshasa' => 'západoafrický čas (Kinshasa)',
        'Africa/Lagos' => 'západoafrický čas (Lagos)',
        'Africa/Libreville' => 'západoafrický čas (Libreville)',
        'Africa/Lome' => 'greenwichský střední čas (Lomé)',
        'Africa/Luanda' => 'západoafrický čas (Luanda)',
        'Africa/Lubumbashi' => 'středoafrický čas (Lubumbashi)',
        'Africa/Lusaka' => 'středoafrický čas (Lusaka)',
        'Africa/Malabo' => 'západoafrický čas (Malabo)',
        'Africa/Maputo' => 'středoafrický čas (Maputo)',
        'Africa/Maseru' => 'jihoafrický čas (Maseru)',
        'Africa/Mbabane' => 'jihoafrický čas (Mbabane)',
        'Africa/Mogadishu' => 'východoafrický čas (Mogadišu)',
        'Africa/Monrovia' => 'greenwichský střední čas (Monrovia)',
        'Africa/Nairobi' => 'východoafrický čas (Nairobi)',
        'Africa/Ndjamena' => 'západoafrický čas (Ndžamena)',
        'Africa/Niamey' => 'západoafrický čas (Niamey)',
        'Africa/Nouakchott' => 'greenwichský střední čas (Nuakšott)',
        'Africa/Ouagadougou' => 'greenwichský střední čas (Ouagadougou)',
        'Africa/Porto-Novo' => 'západoafrický čas (Porto-Novo)',
        'Africa/Sao_Tome' => 'greenwichský střední čas (Svatý Tomáš)',
        'Africa/Tripoli' => 'východoevropský čas (Tripolis)',
        'Africa/Tunis' => 'středoevropský čas (Tunis)',
        'Africa/Windhoek' => 'středoafrický čas (Windhoek)',
        'America/Adak' => 'havajsko-aleutský čas (Adak)',
        'America/Anchorage' => 'aljašský čas (Anchorage)',
        'America/Anguilla' => 'atlantický čas (Anguilla)',
        'America/Antigua' => 'atlantický čas (Antigua)',
        'America/Araguaina' => 'brasilijský čas (Araguaina)',
        'America/Argentina/La_Rioja' => 'argentinský čas (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'argentinský čas (Rio Gallegos)',
        'America/Argentina/Salta' => 'argentinský čas (Salta)',
        'America/Argentina/San_Juan' => 'argentinský čas (San Juan)',
        'America/Argentina/San_Luis' => 'argentinský čas (San Luis)',
        'America/Argentina/Tucuman' => 'argentinský čas (Tucuman)',
        'America/Argentina/Ushuaia' => 'argentinský čas (Ushuaia)',
        'America/Aruba' => 'atlantický čas (Aruba)',
        'America/Asuncion' => 'paraguayský čas (Asunción)',
        'America/Bahia' => 'brasilijský čas (Bahía)',
        'America/Bahia_Banderas' => 'severoamerický centrální čas (Bahia Banderas)',
        'America/Barbados' => 'atlantický čas (Barbados)',
        'America/Belem' => 'brasilijský čas (Belém)',
        'America/Belize' => 'severoamerický centrální čas (Belize)',
        'America/Blanc-Sablon' => 'atlantický čas (Blanc-Sablon)',
        'America/Boa_Vista' => 'amazonský čas (Boa Vista)',
        'America/Bogota' => 'kolumbijský čas (Bogotá)',
        'America/Boise' => 'severoamerický horský čas (Boise)',
        'America/Buenos_Aires' => 'argentinský čas (Buenos Aires)',
        'America/Cambridge_Bay' => 'severoamerický horský čas (Cambridge Bay)',
        'America/Campo_Grande' => 'amazonský čas (Campo Grande)',
        'America/Cancun' => 'severoamerický východní čas (Cancún)',
        'America/Caracas' => 'venezuelský čas (Caracas)',
        'America/Catamarca' => 'argentinský čas (Catamarca)',
        'America/Cayenne' => 'francouzskoguyanský čas (Cayenne)',
        'America/Cayman' => 'severoamerický východní čas (Kajmanské ostrovy)',
        'America/Chicago' => 'severoamerický centrální čas (Chicago)',
        'America/Chihuahua' => 'severoamerický centrální čas (Chihuahua)',
        'America/Ciudad_Juarez' => 'severoamerický horský čas (Ciudad Juárez)',
        'America/Coral_Harbour' => 'severoamerický východní čas (Atikokan)',
        'America/Cordoba' => 'argentinský čas (Córdoba)',
        'America/Costa_Rica' => 'severoamerický centrální čas (Kostarika)',
        'America/Creston' => 'severoamerický horský čas (Creston)',
        'America/Cuiaba' => 'amazonský čas (Cuiaba)',
        'America/Curacao' => 'atlantický čas (Curaçao)',
        'America/Danmarkshavn' => 'greenwichský střední čas (Danmarkshavn)',
        'America/Dawson' => 'yukonský čas (Dawson)',
        'America/Dawson_Creek' => 'severoamerický horský čas (Dawson Creek)',
        'America/Denver' => 'severoamerický horský čas (Denver)',
        'America/Detroit' => 'severoamerický východní čas (Detroit)',
        'America/Dominica' => 'atlantický čas (Dominika)',
        'America/Edmonton' => 'severoamerický horský čas (Edmonton)',
        'America/Eirunepe' => 'Acrejský čas (Eirunepe)',
        'America/El_Salvador' => 'severoamerický centrální čas (Salvador)',
        'America/Fort_Nelson' => 'severoamerický horský čas (Fort Nelson)',
        'America/Fortaleza' => 'brasilijský čas (Fortaleza)',
        'America/Glace_Bay' => 'atlantický čas (Glace Bay)',
        'America/Godthab' => 'západogrónský čas (Nuuk)',
        'America/Goose_Bay' => 'atlantický čas (Goose Bay)',
        'America/Grand_Turk' => 'severoamerický východní čas (Grand Turk)',
        'America/Grenada' => 'atlantický čas (Grenada)',
        'America/Guadeloupe' => 'atlantický čas (Guadeloupe)',
        'America/Guatemala' => 'severoamerický centrální čas (Guatemala)',
        'America/Guayaquil' => 'ekvádorský čas (Guayaquil)',
        'America/Guyana' => 'guyanský čas (Guyana)',
        'America/Halifax' => 'atlantický čas (Halifax)',
        'America/Havana' => 'kubánský čas (Havana)',
        'America/Hermosillo' => 'mexický pacifický čas (Hermosillo)',
        'America/Indiana/Knox' => 'severoamerický centrální čas (Knox, Indiana)',
        'America/Indiana/Marengo' => 'severoamerický východní čas (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'severoamerický východní čas (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'severoamerický centrální čas (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'severoamerický východní čas (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'severoamerický východní čas (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'severoamerický východní čas (Winamac, Indiana)',
        'America/Indianapolis' => 'severoamerický východní čas (Indianapolis)',
        'America/Inuvik' => 'severoamerický horský čas (Inuvik)',
        'America/Iqaluit' => 'severoamerický východní čas (Iqaluit)',
        'America/Jamaica' => 'severoamerický východní čas (Jamajka)',
        'America/Jujuy' => 'argentinský čas (Jujuy)',
        'America/Juneau' => 'aljašský čas (Juneau)',
        'America/Kentucky/Monticello' => 'severoamerický východní čas (Monticello, Kentucky)',
        'America/Kralendijk' => 'atlantický čas (Kralendijk)',
        'America/La_Paz' => 'bolivijský čas (La Paz)',
        'America/Lima' => 'peruánský čas (Lima)',
        'America/Los_Angeles' => 'severoamerický pacifický čas (Los Angeles)',
        'America/Louisville' => 'severoamerický východní čas (Louisville)',
        'America/Lower_Princes' => 'atlantický čas (Lower Prince’s Quarter)',
        'America/Maceio' => 'brasilijský čas (Maceio)',
        'America/Managua' => 'severoamerický centrální čas (Managua)',
        'America/Manaus' => 'amazonský čas (Manaus)',
        'America/Marigot' => 'atlantický čas (Marigot)',
        'America/Martinique' => 'atlantický čas (Martinik)',
        'America/Matamoros' => 'severoamerický centrální čas (Matamoros)',
        'America/Mazatlan' => 'mexický pacifický čas (Mazatlán)',
        'America/Mendoza' => 'argentinský čas (Mendoza)',
        'America/Menominee' => 'severoamerický centrální čas (Menominee)',
        'America/Merida' => 'severoamerický centrální čas (Merida)',
        'America/Metlakatla' => 'aljašský čas (Metlakatla)',
        'America/Mexico_City' => 'severoamerický centrální čas (Ciudad de México)',
        'America/Miquelon' => 'pierre-miquelonský čas',
        'America/Moncton' => 'atlantický čas (Moncton)',
        'America/Monterrey' => 'severoamerický centrální čas (Monterrey)',
        'America/Montevideo' => 'uruguayský čas (Montevideo)',
        'America/Montserrat' => 'atlantický čas (Montserrat)',
        'America/Nassau' => 'severoamerický východní čas (Nassau)',
        'America/New_York' => 'severoamerický východní čas (New York)',
        'America/Nipigon' => 'severoamerický východní čas (Nipigon)',
        'America/Nome' => 'aljašský čas (Nome)',
        'America/Noronha' => 'čas souostroví Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'severoamerický centrální čas (Beulah, Severní Dakota)',
        'America/North_Dakota/Center' => 'severoamerický centrální čas (Center, Severní Dakota)',
        'America/North_Dakota/New_Salem' => 'severoamerický centrální čas (New Salem, Severní Dakota)',
        'America/Ojinaga' => 'severoamerický centrální čas (Ojinaga)',
        'America/Panama' => 'severoamerický východní čas (Panama)',
        'America/Pangnirtung' => 'severoamerický východní čas (Pangnirtung)',
        'America/Paramaribo' => 'surinamský čas (Paramaribo)',
        'America/Phoenix' => 'severoamerický horský čas (Phoenix)',
        'America/Port-au-Prince' => 'severoamerický východní čas (Port-au-Prince)',
        'America/Port_of_Spain' => 'atlantický čas (Port of Spain)',
        'America/Porto_Velho' => 'amazonský čas (Porto Velho)',
        'America/Puerto_Rico' => 'atlantický čas (Portoriko)',
        'America/Punta_Arenas' => 'chilský čas (Punta Arenas)',
        'America/Rainy_River' => 'severoamerický centrální čas (Rainy River)',
        'America/Rankin_Inlet' => 'severoamerický centrální čas (Rankin Inlet)',
        'America/Recife' => 'brasilijský čas (Recife)',
        'America/Regina' => 'severoamerický centrální čas (Regina)',
        'America/Resolute' => 'severoamerický centrální čas (Resolute)',
        'America/Rio_Branco' => 'Acrejský čas (Rio Branco)',
        'America/Santa_Isabel' => 'severozápadní mexický čas (Santa Isabel)',
        'America/Santarem' => 'brasilijský čas (Santarém)',
        'America/Santiago' => 'chilský čas (Santiago)',
        'America/Santo_Domingo' => 'atlantický čas (Santo Domingo)',
        'America/Sao_Paulo' => 'brasilijský čas (São Paulo)',
        'America/Scoresbysund' => 'východogrónský čas (Ittoqqortoormiit)',
        'America/Sitka' => 'aljašský čas (Sitka)',
        'America/St_Barthelemy' => 'atlantický čas (Svatý Bartoloměj)',
        'America/St_Johns' => 'newfoundlandský čas (St. John’s)',
        'America/St_Kitts' => 'atlantický čas (Svatý Kryštof)',
        'America/St_Lucia' => 'atlantický čas (Svatá Lucie)',
        'America/St_Thomas' => 'atlantický čas (Svatý Tomáš (Karibik))',
        'America/St_Vincent' => 'atlantický čas (Svatý Vincenc)',
        'America/Swift_Current' => 'severoamerický centrální čas (Swift Current)',
        'America/Tegucigalpa' => 'severoamerický centrální čas (Tegucigalpa)',
        'America/Thule' => 'atlantický čas (Thule)',
        'America/Thunder_Bay' => 'severoamerický východní čas (Thunder Bay)',
        'America/Tijuana' => 'severoamerický pacifický čas (Tijuana)',
        'America/Toronto' => 'severoamerický východní čas (Toronto)',
        'America/Tortola' => 'atlantický čas (Tortola)',
        'America/Vancouver' => 'severoamerický pacifický čas (Vancouver)',
        'America/Whitehorse' => 'yukonský čas (Whitehorse)',
        'America/Winnipeg' => 'severoamerický centrální čas (Winnipeg)',
        'America/Yakutat' => 'aljašský čas (Yakutat)',
        'America/Yellowknife' => 'severoamerický horský čas (Yellowknife)',
        'Antarctica/Casey' => 'Čas Caseyho stanice',
        'Antarctica/Davis' => 'čas Davisovy stanice',
        'Antarctica/DumontDUrville' => 'čas stanice Dumonta d’Urvilla (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'východoaustralský čas (Macquarie)',
        'Antarctica/Mawson' => 'čas Mawsonovy stanice',
        'Antarctica/McMurdo' => 'novozélandský čas (McMurdo)',
        'Antarctica/Palmer' => 'chilský čas (Palmer)',
        'Antarctica/Rothera' => 'čas Rotherovy stanice (Rothera)',
        'Antarctica/Syowa' => 'čas stanice Šówa (Syowa)',
        'Antarctica/Troll' => 'greenwichský střední čas (Troll)',
        'Antarctica/Vostok' => 'čas stanice Vostok',
        'Arctic/Longyearbyen' => 'středoevropský čas (Longyearbyen)',
        'Asia/Aden' => 'arabský čas (Aden)',
        'Asia/Almaty' => 'východokazachstánský čas (Almaty)',
        'Asia/Amman' => 'východoevropský čas (Ammán)',
        'Asia/Anadyr' => 'Anadyrský čas',
        'Asia/Aqtau' => 'západokazachstánský čas (Aktau)',
        'Asia/Aqtobe' => 'západokazachstánský čas (Aktobe)',
        'Asia/Ashgabat' => 'turkmenský čas (Ašchabad)',
        'Asia/Atyrau' => 'západokazachstánský čas (Atyrau)',
        'Asia/Baghdad' => 'arabský čas (Bagdád)',
        'Asia/Bahrain' => 'arabský čas (Bahrajn)',
        'Asia/Baku' => 'ázerbájdžánský čas (Baku)',
        'Asia/Bangkok' => 'indočínský čas (Bangkok)',
        'Asia/Barnaul' => 'časové pásmo Rusko (Barnaul)',
        'Asia/Beirut' => 'východoevropský čas (Bejrút)',
        'Asia/Bishkek' => 'kyrgyzský čas (Biškek)',
        'Asia/Brunei' => 'brunejský čas',
        'Asia/Calcutta' => 'indický čas (Kalkata)',
        'Asia/Chita' => 'jakutský čas (Čita)',
        'Asia/Choibalsan' => 'ulánbátarský čas (Čojbalsan)',
        'Asia/Colombo' => 'indický čas (Kolombo)',
        'Asia/Damascus' => 'východoevropský čas (Damašek)',
        'Asia/Dhaka' => 'bangladéšský čas (Dháka)',
        'Asia/Dili' => 'východotimorský čas (Dili)',
        'Asia/Dubai' => 'standardní čas Perského zálivu (Dubaj)',
        'Asia/Dushanbe' => 'tádžický čas (Dušanbe)',
        'Asia/Famagusta' => 'východoevropský čas (Famagusta)',
        'Asia/Gaza' => 'východoevropský čas (Gaza)',
        'Asia/Hebron' => 'východoevropský čas (Hebron)',
        'Asia/Hong_Kong' => 'hongkongský čas',
        'Asia/Hovd' => 'hovdský čas',
        'Asia/Irkutsk' => 'irkutský čas',
        'Asia/Jakarta' => 'západoindonéský čas (Jakarta)',
        'Asia/Jayapura' => 'východoindonéský čas (Jayapura)',
        'Asia/Jerusalem' => 'izraelský čas (Jeruzalém)',
        'Asia/Kabul' => 'afghánský čas (Kábul)',
        'Asia/Kamchatka' => 'Petropavlovsko-kamčatský čas (Kamčatka)',
        'Asia/Karachi' => 'pákistánský čas (Karáčí)',
        'Asia/Katmandu' => 'nepálský čas (Káthmándú)',
        'Asia/Khandyga' => 'jakutský čas (Chandyga)',
        'Asia/Krasnoyarsk' => 'krasnojarský čas',
        'Asia/Kuala_Lumpur' => 'malajský čas (Kuala Lumpur)',
        'Asia/Kuching' => 'malajský čas (Kučing)',
        'Asia/Kuwait' => 'arabský čas (Kuvajt)',
        'Asia/Macau' => 'čínský čas (Macao)',
        'Asia/Magadan' => 'magadanský čas',
        'Asia/Makassar' => 'středoindonéský čas (Makassar)',
        'Asia/Manila' => 'filipínský čas (Manila)',
        'Asia/Muscat' => 'standardní čas Perského zálivu (Maskat)',
        'Asia/Nicosia' => 'východoevropský čas (Nikósie)',
        'Asia/Novokuznetsk' => 'krasnojarský čas (Novokuzněck)',
        'Asia/Novosibirsk' => 'novosibirský čas',
        'Asia/Omsk' => 'omský čas',
        'Asia/Oral' => 'západokazachstánský čas (Uralsk)',
        'Asia/Phnom_Penh' => 'indočínský čas (Phnompenh)',
        'Asia/Pontianak' => 'západoindonéský čas (Pontianak)',
        'Asia/Pyongyang' => 'korejský čas (Pchjongjang)',
        'Asia/Qatar' => 'arabský čas (Katar)',
        'Asia/Qostanay' => 'východokazachstánský čas (Kostanaj)',
        'Asia/Qyzylorda' => 'západokazachstánský čas (Kyzylorda)',
        'Asia/Rangoon' => 'myanmarský čas (Rangún)',
        'Asia/Riyadh' => 'arabský čas (Rijád)',
        'Asia/Saigon' => 'indočínský čas (Ho Či Minovo město)',
        'Asia/Sakhalin' => 'sachalinský čas',
        'Asia/Samarkand' => 'uzbecký čas (Samarkand)',
        'Asia/Seoul' => 'korejský čas (Soul)',
        'Asia/Shanghai' => 'čínský čas (Šanghaj)',
        'Asia/Singapore' => 'singapurský čas',
        'Asia/Srednekolymsk' => 'magadanský čas (Sredněkolymsk)',
        'Asia/Taipei' => 'tchajpejský čas (Tchaj-pej)',
        'Asia/Tashkent' => 'uzbecký čas (Taškent)',
        'Asia/Tbilisi' => 'gruzínský čas (Tbilisi)',
        'Asia/Tehran' => 'íránský čas (Teherán)',
        'Asia/Thimphu' => 'bhútánský čas (Thimbú)',
        'Asia/Tokyo' => 'japonský čas (Tokio)',
        'Asia/Tomsk' => 'časové pásmo Rusko (Tomsk)',
        'Asia/Ulaanbaatar' => 'ulánbátarský čas',
        'Asia/Urumqi' => 'časové pásmo Čína (Urumči)',
        'Asia/Ust-Nera' => 'vladivostocký čas (Ust-Nera)',
        'Asia/Vientiane' => 'indočínský čas (Vientiane)',
        'Asia/Vladivostok' => 'vladivostocký čas (Vladivostok)',
        'Asia/Yakutsk' => 'jakutský čas',
        'Asia/Yekaterinburg' => 'jekatěrinburský čas (Jekatěrinburg)',
        'Asia/Yerevan' => 'arménský čas (Jerevan)',
        'Atlantic/Azores' => 'azorský čas (Azorské ostrovy)',
        'Atlantic/Bermuda' => 'atlantický čas (Bermudy)',
        'Atlantic/Canary' => 'západoevropský čas (Kanárské ostrovy)',
        'Atlantic/Cape_Verde' => 'kapverdský čas (Kapverdy)',
        'Atlantic/Faeroe' => 'západoevropský čas (Faerské ostrovy)',
        'Atlantic/Madeira' => 'západoevropský čas (Madeira)',
        'Atlantic/Reykjavik' => 'greenwichský střední čas (Reykjavík)',
        'Atlantic/South_Georgia' => 'čas Jižní Georgie',
        'Atlantic/St_Helena' => 'greenwichský střední čas (Svatá Helena)',
        'Atlantic/Stanley' => 'falklandský čas (Stanley)',
        'Australia/Adelaide' => 'středoaustralský čas (Adelaide)',
        'Australia/Brisbane' => 'východoaustralský čas (Brisbane)',
        'Australia/Broken_Hill' => 'středoaustralský čas (Broken Hill)',
        'Australia/Currie' => 'východoaustralský čas (Currie)',
        'Australia/Darwin' => 'středoaustralský čas (Darwin)',
        'Australia/Eucla' => 'středozápadní australský čas (Eucla)',
        'Australia/Hobart' => 'východoaustralský čas (Hobart)',
        'Australia/Lindeman' => 'východoaustralský čas (Lindeman)',
        'Australia/Lord_Howe' => 'čas ostrova lorda Howa (Lord Howe)',
        'Australia/Melbourne' => 'východoaustralský čas (Melbourne)',
        'Australia/Perth' => 'západoaustralský čas (Perth)',
        'Australia/Sydney' => 'východoaustralský čas (Sydney)',
        'CST6CDT' => 'severoamerický centrální čas',
        'EST5EDT' => 'severoamerický východní čas',
        'Etc/GMT' => 'greenwichský střední čas',
        'Etc/UTC' => 'koordinovaný světový čas',
        'Europe/Amsterdam' => 'středoevropský čas (Amsterdam)',
        'Europe/Andorra' => 'středoevropský čas (Andorra)',
        'Europe/Astrakhan' => 'moskevský čas (Astrachaň)',
        'Europe/Athens' => 'východoevropský čas (Athény)',
        'Europe/Belgrade' => 'středoevropský čas (Bělehrad)',
        'Europe/Berlin' => 'středoevropský čas (Berlín)',
        'Europe/Bratislava' => 'středoevropský čas (Bratislava)',
        'Europe/Brussels' => 'středoevropský čas (Brusel)',
        'Europe/Bucharest' => 'východoevropský čas (Bukurešť)',
        'Europe/Budapest' => 'středoevropský čas (Budapešť)',
        'Europe/Busingen' => 'středoevropský čas (Busingen)',
        'Europe/Chisinau' => 'východoevropský čas (Kišiněv)',
        'Europe/Copenhagen' => 'středoevropský čas (Kodaň)',
        'Europe/Dublin' => 'greenwichský střední čas (Dublin)',
        'Europe/Gibraltar' => 'středoevropský čas (Gibraltar)',
        'Europe/Guernsey' => 'greenwichský střední čas (Guernsey)',
        'Europe/Helsinki' => 'východoevropský čas (Helsinky)',
        'Europe/Isle_of_Man' => 'greenwichský střední čas (Ostrov Man)',
        'Europe/Istanbul' => 'časové pásmo Turecko (Istanbul)',
        'Europe/Jersey' => 'greenwichský střední čas (Jersey)',
        'Europe/Kaliningrad' => 'východoevropský čas (Kaliningrad)',
        'Europe/Kiev' => 'východoevropský čas (Kyjev)',
        'Europe/Kirov' => 'časové pásmo Rusko (Kirov)',
        'Europe/Lisbon' => 'západoevropský čas (Lisabon)',
        'Europe/Ljubljana' => 'středoevropský čas (Lublaň)',
        'Europe/London' => 'greenwichský střední čas (Londýn)',
        'Europe/Luxembourg' => 'středoevropský čas (Lucemburk)',
        'Europe/Madrid' => 'středoevropský čas (Madrid)',
        'Europe/Malta' => 'středoevropský čas (Malta)',
        'Europe/Mariehamn' => 'východoevropský čas (Mariehamn)',
        'Europe/Minsk' => 'moskevský čas (Minsk)',
        'Europe/Monaco' => 'středoevropský čas (Monako)',
        'Europe/Moscow' => 'moskevský čas (Moskva)',
        'Europe/Oslo' => 'středoevropský čas (Oslo)',
        'Europe/Paris' => 'středoevropský čas (Paříž)',
        'Europe/Podgorica' => 'středoevropský čas (Podgorica)',
        'Europe/Prague' => 'středoevropský čas (Praha)',
        'Europe/Riga' => 'východoevropský čas (Riga)',
        'Europe/Rome' => 'středoevropský čas (Řím)',
        'Europe/Samara' => 'Samarský čas (Samara)',
        'Europe/San_Marino' => 'středoevropský čas (San Marino)',
        'Europe/Sarajevo' => 'středoevropský čas (Sarajevo)',
        'Europe/Saratov' => 'moskevský čas (Saratov)',
        'Europe/Simferopol' => 'moskevský čas (Simferopol)',
        'Europe/Skopje' => 'středoevropský čas (Skopje)',
        'Europe/Sofia' => 'východoevropský čas (Sofie)',
        'Europe/Stockholm' => 'středoevropský čas (Stockholm)',
        'Europe/Tallinn' => 'východoevropský čas (Tallinn)',
        'Europe/Tirane' => 'středoevropský čas (Tirana)',
        'Europe/Ulyanovsk' => 'moskevský čas (Uljanovsk)',
        'Europe/Uzhgorod' => 'východoevropský čas (Užhorod)',
        'Europe/Vaduz' => 'středoevropský čas (Vaduz)',
        'Europe/Vatican' => 'středoevropský čas (Vatikán)',
        'Europe/Vienna' => 'středoevropský čas (Vídeň)',
        'Europe/Vilnius' => 'východoevropský čas (Vilnius)',
        'Europe/Volgograd' => 'volgogradský čas',
        'Europe/Warsaw' => 'středoevropský čas (Varšava)',
        'Europe/Zagreb' => 'středoevropský čas (Záhřeb)',
        'Europe/Zaporozhye' => 'východoevropský čas (Záporoží)',
        'Europe/Zurich' => 'středoevropský čas (Curych)',
        'Indian/Antananarivo' => 'východoafrický čas (Antananarivo)',
        'Indian/Chagos' => 'indickooceánský čas (Chagos)',
        'Indian/Christmas' => 'čas Vánočního ostrova (Vánoční ostrov)',
        'Indian/Cocos' => 'čas Kokosových ostrovů (Kokosové ostrovy)',
        'Indian/Comoro' => 'východoafrický čas (Komory)',
        'Indian/Kerguelen' => 'čas Francouzských jižních a antarktických území (Kerguelenovy ostrovy)',
        'Indian/Mahe' => 'seychelský čas (Mahé)',
        'Indian/Maldives' => 'maledivský čas (Maledivy)',
        'Indian/Mauritius' => 'mauricijský čas (Mauricius)',
        'Indian/Mayotte' => 'východoafrický čas (Mayotte)',
        'Indian/Reunion' => 'réunionský čas',
        'MST7MDT' => 'severoamerický horský čas',
        'PST8PDT' => 'severoamerický pacifický čas',
        'Pacific/Apia' => 'apijský čas (Apia)',
        'Pacific/Auckland' => 'novozélandský čas (Auckland)',
        'Pacific/Bougainville' => 'čas Papuy-Nové Guiney (Bougainville)',
        'Pacific/Chatham' => 'chathamský čas (Chathamské ostrovy)',
        'Pacific/Easter' => 'čas Velikonočního ostrova (Velikonoční ostrov)',
        'Pacific/Efate' => 'vanuatský čas (Éfaté)',
        'Pacific/Enderbury' => 'čas Fénixových ostrovů (Enderbury)',
        'Pacific/Fakaofo' => 'tokelauský čas (Fakaofo)',
        'Pacific/Fiji' => 'fidžijský čas',
        'Pacific/Funafuti' => 'tuvalský čas (Funafuti)',
        'Pacific/Galapagos' => 'galapážský čas (Galapágy)',
        'Pacific/Gambier' => 'gambierský čas (Gambierovy ostrovy)',
        'Pacific/Guadalcanal' => 'čas Šalamounových ostrovů (Guadalcanal)',
        'Pacific/Guam' => 'chamorrský čas (Guam)',
        'Pacific/Honolulu' => 'havajsko-aleutský čas (Honolulu)',
        'Pacific/Johnston' => 'havajsko-aleutský čas (Johnston)',
        'Pacific/Kiritimati' => 'čas Rovníkových ostrovů (Kiritimati)',
        'Pacific/Kosrae' => 'kosrajský čas (Kosrae)',
        'Pacific/Kwajalein' => 'čas Marshallových ostrovů (Kwajalein)',
        'Pacific/Majuro' => 'čas Marshallových ostrovů (Majuro)',
        'Pacific/Marquesas' => 'markézský čas (Markézy)',
        'Pacific/Midway' => 'samojský čas (Midway)',
        'Pacific/Nauru' => 'naurský čas (Nauru)',
        'Pacific/Niue' => 'niuejský čas',
        'Pacific/Norfolk' => 'norfolkský čas',
        'Pacific/Noumea' => 'novokaledonský čas (Nouméa)',
        'Pacific/Pago_Pago' => 'samojský čas (Pago Pago)',
        'Pacific/Palau' => 'palauský čas',
        'Pacific/Pitcairn' => 'čas Pitcairnových ostrovů (Pitcairnovy ostrovy)',
        'Pacific/Ponape' => 'ponapský čas (Pohnpei)',
        'Pacific/Port_Moresby' => 'čas Papuy-Nové Guiney (Port Moresby)',
        'Pacific/Rarotonga' => 'čas Cookových ostrovů (Rarotonga)',
        'Pacific/Saipan' => 'chamorrský čas (Saipan)',
        'Pacific/Tahiti' => 'tahitský čas (Tahiti)',
        'Pacific/Tarawa' => 'čas Gilbertových ostrovů (Tarawa)',
        'Pacific/Tongatapu' => 'tonžský čas (Tongatapu)',
        'Pacific/Truk' => 'chuukský čas (Chuukské ostrovy)',
        'Pacific/Wake' => 'čas ostrova Wake',
        'Pacific/Wallis' => 'čas ostrovů Wallis a Futuna',
    ],
    'Meta' => [
        'HourFormatPos' => '+%d:%02d',
        'HourFormatNeg' => '-%d:%02d',
    ],
];
